==> amarok-1.83.tar.bz2: amarok-1.83/src/playlist/RandomTrackNavigator.h <==
/***************************************************************************
 * copyright            : (C) 2008 Seb Ruiz <ruiz@kde.org>    
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy 
 * defined in Section 14 of version 3 of the license.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/

#ifndef AMAROK_RANDOMTRACKNAVIGATOR_H
#define AMAROK_RANDOMTRACKNAVIGATOR_H

#include "meta/Meta.h"
#include "playlist/PlaylistModel.h"
#include "playlist/PlaylistRowList.h"
#include "playlist/TrackNavigator.h"

namespace Playlist {
    class Model;
    /**
     * Plays a random track in the playlist
     */
    class RandomTrackNavigator : public TrackNavigator
    {
        public:
            RandomTrackNavigator( Model *m ) : TrackNavigator( m ) {}

            int nextRow();
            int lastRow();

        private:
            void generateUnplayedRows();
            RowList m_playedRows;
            RowList m_unplayedRows;
    };

 }

#endif

==> amarok-1.92.tar.bz2: amarok-1.92/src/playlist/RandomTrackNavigator.h <==
/***************************************************************************
 * copyright            : (C) 2008 Seb Ruiz <ruiz@kde.org>    
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy 
 * defined in Section 14 of version 3 of the license.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/

#ifndef AMAROK_RANDOMTRACKNAVIGATOR_H
#define AMAROK_RANDOMTRACKNAVIGATOR_H

#include "meta/Meta.h"
#include "playlist/PlaylistModel.h"
#include "playlist/PlaylistRowList.h"
#include "playlist/SimpleTrackNavigator.h"

namespace Playlist {
    class Model;
    /**
     * Plays a random track in the playlist
     */
    class RandomTrackNavigator : public SimpleTrackNavigator
    {
        public:
            RandomTrackNavigator( Model *m ) : SimpleTrackNavigator( m ) {}

        private:
            int nextRow();
            int lastRow();

            void generateUnplayedRows();
            RowList m_playedRows;
            RowList m_unplayedRows;
    };

 }

#endif
